@@ -44,6 +44,7 @@ class NodeMeta(BaseModel):
 
 
 class NodeConfig(BaseModel):
+    enabled: bool = True
     materialized: Optional[str]
     on_schema_change: Optional[OnSchemaChange]
     sql_header: Optional[str]
@@ -61,6 +62,15 @@ class ManifestColumn(BaseModel):
     data_type: Optional[str]
 
 
+class ExternalConfig(BaseModel):
+    location: str
+    dry_run_columns: List[ManifestColumn] = Field(default_factory=lambda: list())
+
+    @property
+    def dry_run_columns_map(self) -> Dict[str, ManifestColumn]:
+        return {c.name: c for c in self.dry_run_columns}
+
+
 class Node(BaseModel):
     name: str
     config: NodeConfig
@@ -77,7 +87,7 @@ class Node(BaseModel):
     root_path: str
     columns: Dict[str, ManifestColumn]
     meta: Optional[NodeMeta]
-    external: Optional[Dict[str, Any]]
+    external: Optional[ExternalConfig]
 
     def __init__(self, **data: Any):
         super().__init__(
